<?php

namespace Drupal\hubspot_integration\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\hubspot_integration\Services\HubspotAPI;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

class HubspotAPIAjaxController extends ControllerBase {

  protected $hubspot_api;

  /**
   * Constructs a HubspotAPIAjaxController object.
   *
   * @param \Drupal\hubspot_integration\Services\HubspotAPI $hubspot_api
   *   The HubspotApi service.
   */
  public function __construct(HubspotAPI $hubspot_api) {
    $this->hubspot_api = $hubspot_api;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('hubspot_integration.api')
    );
  }

  public function isContact() {
    $tids = $this->hubspot_api->getUserTids();

    return new JsonResponse([
      'data' => [
        'is_contact' => !empty($tids),
        'cookie' => 'hubspot_' . implode('_', $tids),
      ],
    ]);
  }

  public function isLimitReached() {
    $isLimitReached = FALSE;

    $config = $this->hubspot_api;
    $anonymousContactNumber = $config->getAnonymousContactNumber();
    $anonymousMaxContact = $config->getConfig('anonymous_max_contact');

    if ($anonymousMaxContact != NULL
      && $anonymousMaxContact != 0
      && $anonymousContactNumber < $anonymousMaxContact) {
      $isLimitReached = TRUE;
    }

    return new JsonResponse([
      'data' => [
        'is_limit_reached' => $isLimitReached,
      ],
    ]);
  }

}
